@@ -39,20 +39,14 @@ typedef boost::shared_ptr<audio_alsa_sink> audio_alsa_sink_sptr;
 /*!
  * \brief make an alsa audio sink.
  *
- * \param sampling_freq	sampling rate in Hz
+ * \param sampling_rate	sampling rate in Hz
  * \param dev ALSA pcm device name, e.g., "hw:0,0"
- * \param period_time duration of a single period in seconds
- * \param nperiods number of periods
- *
- * \p period_time and \p nperiods determine the total buffering
- * used.  \p period_time is length in seconds of a single fragment.
- * \p nperiods * \p period_time gives the total buffer duration.
+ * \param ok_to_block (currently ignored)
  */
 audio_alsa_sink_sptr
-audio_alsa_make_sink (int sampling_freq,
+audio_alsa_make_sink (int sampling_rate,
 		      const std::string dev = "",
-		      double period_time = -1,
-		      int nperiods = -1);
+		      bool ok_to_block = true);
 
 /*!
  * \brief audio sink using ALSA
@@ -64,15 +58,15 @@ audio_alsa_make_sink (int sampling_freq,
  */
 class audio_alsa_sink : public gr_sync_block {
   friend audio_alsa_sink_sptr
-  audio_alsa_make_sink (int sampling_freq, const std::string device_name,
-			double period_time, int nperiods);
+  audio_alsa_make_sink (int sampling_rate, const std::string device_name,
+			bool ok_to_block);
 
   // typedef for pointer to class work method
   typedef int (audio_alsa_sink::*work_t)(int noutput_items,
 					 gr_vector_const_void_star &input_items,
 					 gr_vector_void_star &output_items);
 
-  unsigned int		d_sampling_freq;
+  unsigned int		d_sampling_rate;
   std::string		d_device_name;
   snd_pcm_t            *d_pcm_handle;
   snd_pcm_hw_params_t  *d_hw_params;
@@ -94,8 +88,8 @@ class audio_alsa_sink : public gr_sync_block {
   void bail (const char *msg, int err) throw (std::runtime_error);
 
  protected:
-  audio_alsa_sink (int sampling_freq, const std::string device_name,
-		   double period_time, int nperiods);
+  audio_alsa_sink (int sampling_rate, const std::string device_name,
+		   bool ok_to_block);
 
  public:
   ~audio_alsa_sink ();
