@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2006 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -36,22 +36,16 @@ class audio_alsa_source;
 typedef boost::shared_ptr<audio_alsa_source> audio_alsa_source_sptr;
 
 /*!
- * \brief make an alsa audio source.
+ * \brief Make an ALSA audio source.
  *
- * \param sampling_freq	sampling rate
+ * \param sampling_rate	sampling rate
  * \param dev ALSA pcm device name, e.g., "hw:0,0"
- * \param period_time time of a single period in seconds
- * \param nperiods number of periods
- *
- * \p period_time and \p nperiods determine the total buffering
- * used.  period_time is length in seconds of a single fragment.
- * nperiods * period_time gives the total buffer.
+ * \param ok_to_block  (currently ignored)
  */
 audio_alsa_source_sptr
-audio_alsa_make_source (int sampling_freq,
+audio_alsa_make_source (int sampling_rate,
 			const std::string dev = "",
-			double period_time = -1,
-			int nperiods = -1);
+			bool ok_to_block = true);
 
 /*!
  * \brief audio source using ALSA
@@ -63,15 +57,16 @@ audio_alsa_make_source (int sampling_freq,
  */
 class audio_alsa_source : public gr_sync_block {
   friend audio_alsa_source_sptr
-  audio_alsa_make_source (int sampling_freq, const std::string device_name,
-			  double period_time, int nperiods);
+  audio_alsa_make_source (int sampling_rate,
+			  const std::string device_name,
+			  bool ok_to_block);
 
   // typedef for pointer to class work method
   typedef int (audio_alsa_source::*work_t)(int noutput_items,
 					   gr_vector_const_void_star &input_items,
 					   gr_vector_void_star &output_items);
 
-  unsigned int		d_sampling_freq;
+  unsigned int		d_sampling_rate;
   std::string		d_device_name;
   snd_pcm_t            *d_pcm_handle;
   snd_pcm_hw_params_t  *d_hw_params;
@@ -94,8 +89,8 @@ class audio_alsa_source : public gr_sync_block {
   void bail (const char *msg, int err) throw (std::runtime_error);
 
  protected:
-  audio_alsa_source (int sampling_freq, const std::string device_name,
-		     double period_time, int nperiods);
+  audio_alsa_source (int sampling_rate, const std::string device_name,
+		     bool ok_to_block);
 
  public:
   ~audio_alsa_source ();
